@@ -63,7 +63,7 @@ SUPPORTED_PARAMS_FOR_DEVICE: Dict[str, str] = {
     "8B": "I,O,Sp",
     "8D": "I,O,M,AM,Ak",
     "8F": "D,Sg,Sd,St,Ss,Sp,AM,La,Ld",
-    "91": "I,O,M",
+    "91": "I,O,D,M",
 }
 
 UNITS_EN: Dict[str, str] = {
