@@ -4,16 +4,10 @@ from aiohttp import ClientSession
 
 from .baseApi import BaseAPI
 from .channel import Channel
-from .const import (
-    _LOGGER,
-    DEVICES,
-    SUPPORTED_PARAMS_FOR_DEVICE,
-    ChannelType,
-    ReadOnlyClass,
-)
+from .const import _LOGGER, DEVICES, SUPPORTED_PARAMS_FOR_DEVICE, ChannelType
 
 
-class Device(BaseAPI, metaclass=ReadOnlyClass):
+class Device(BaseAPI):
     """Class to interact with a device."""
 
     def __init__(
